@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of REANA.
-# Copyright (C) 2018 CERN.
+# Copyright (C) 2018, 2019, 2020, 2021 CERN.
 #
 # REANA is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
@@ -26,7 +26,7 @@ class REANAConfig:
     @classmethod
     def _read_file(cls, filename):
         with open(os.path.join(cls.path, filename)) as yaml_file:
-            data = yaml.load(yaml_file)
+            data = yaml.load(yaml_file, Loader=yaml.FullLoader)
             return data
 
     @classmethod
@@ -117,20 +117,44 @@ REANA_RUNTIME_KUBERNETES_NAMESPACE = os.getenv(
 By default runtime pods will run in the same namespace as the infrastructure pods.
 """
 
-REANA_RUNTIME_KUBERNETES_NODE_LABEL = (
-    {
-        os.getenv("REANA_RUNTIME_KUBERNETES_NODE_LABEL")
-        .split("=")[0]: os.getenv("REANA_RUNTIME_KUBERNETES_NODE_LABEL")
-        .split("=")[1]
-    }
-    if os.getenv("REANA_RUNTIME_KUBERNETES_NODE_LABEL")
-    else {}
+
+def kubernetes_node_label_to_dict(node_label):
+    """Load Kubernetes node label to Python dict."""
+    if node_label:
+        label_name, value = node_label.split("=")
+        return {label_name: value}
+
+    return {}
+
+
+REANA_RUNTIME_BATCH_KUBERNETES_NODE_LABEL = kubernetes_node_label_to_dict(
+    os.getenv("REANA_RUNTIME_BATCH_KUBERNETES_NODE_LABEL")
 )
-"""Kubernetes label (with format ``lable_name=lable_value``) which identifies the nodes where the runtime pods should run.
+"""Kubernetes label (with format ``label_name=label_value``) which identifies the nodes where the runtime batch workflows should run.
 
 If not set, the runtime pods run in any available node in the cluster.
 """
 
+REANA_RUNTIME_JOBS_KUBERNETES_NODE_LABEL = kubernetes_node_label_to_dict(
+    os.getenv("REANA_RUNTIME_JOBS_KUBERNETES_NODE_LABEL")
+)
+"""Kubernetes label (with format ``label_name=label_value``) which identifies the nodes where the runtime jobs should run.
+
+If not set, the runtime pods run in any available node in the cluster.
+"""
+
+REANA_RUNTIME_SESSIONS_KUBERNETES_NODE_LABEL = kubernetes_node_label_to_dict(
+    os.getenv(
+        "REANA_RUNTIME_SESSIONS_KUBERNETES_NODE_LABEL",
+        os.getenv("REANA_RUNTIME_JOBS_KUBERNETES_NODE_LABEL"),
+    )
+)
+"""Kubernetes label (with format ``label_name=label_value``) which identifies the nodes where the runtime sessions should run.
+
+If not set, the runtime sessions run in the same nodes as runtime jobs if ``REANA_RUNTIME_JOBS_KUBERNETES_NODE_LABEL`` is set,
+otherwise, they will be allocated in any available node in the cluster.
+"""
+
 
 MQ_HOST = REANA_INFRASTRUCTURE_COMPONENTS_HOSTNAMES["message-broker"]
 """Message queue (RabbitMQ) server host name."""
@@ -155,6 +179,9 @@ MQ_DEFAULT_FORMAT = "json"
 MQ_DEFAULT_EXCHANGE = ""
 """Message queue (RabbitMQ) exchange."""
 
+MQ_MAX_PRIORITY = 100
+"""Declare the queue as a priority queue and set the highest priority number."""
+
 MQ_DEFAULT_QUEUES = {
     "jobs-status": {
         "routing_key": "jobs-status",
@@ -165,6 +192,7 @@ MQ_DEFAULT_QUEUES = {
         "routing_key": "workflow-submission",
         "exchange": MQ_DEFAULT_EXCHANGE,
         "durable": True,
+        "max_priority": MQ_MAX_PRIORITY,
     },
 }
 """Default message queues."""
@@ -308,6 +336,27 @@ REANA_USER_SECRET_MOUNT_PATH = os.getenv(
 SHARED_VOLUME_PATH = os.getenv("SHARED_VOLUME_PATH", "/var/reana")
 """Default shared volume path."""
 
+
+def workspaces(paths):
+    """Tranform list of mounted workspaces as strings, to dictionary of pairs as cluster_node_path:cluster_pod_mountpath."""
+    if isinstance(paths, list):
+        return dict(p.split(":") for p in paths)
+    return paths
+
+
+WORKSPACE_PATHS = workspaces(json.loads(os.getenv("WORKSPACE_PATHS", "{}")))
+"""Dictionary of available workspace paths with pairs of cluster_node_path:cluster_pod_mountpath."""
+
+
+def default_workspace():
+    """Obtain default workspace path."""
+    workspaces_list = [path for path in list(WORKSPACE_PATHS.values())]
+    return workspaces_list[0] if workspaces_list else SHARED_VOLUME_PATH
+
+
+DEFAULT_WORKSPACE_PATH = default_workspace()
+"""Default workspace path defined by the admin."""
+
 K8S_CERN_EOS_MOUNT_CONFIGURATION = {
     "volume": {"name": "eos", "hostPath": {"path": "/var/eos"}},
     "volumeMounts": {
@@ -353,12 +402,27 @@ HTCONDOR_JOB_FLAVOURS = {
     "testmatch": 259200,
     "nextweek": 604800,
 }
-
 """HTCondor job flavours and their respective runtime in seconds."""
 
-REANA_RUNTIME_KUBERNETES_KEEP_ALIVE_JOBS_WITH_STATUSES = os.getenv(
-    "REANA_RUNTIME_KUBERNETES_KEEP_ALIVE_JOBS_WITH_STATUSES", ""
-).split(",")
+REANA_RESOURCE_HEALTH_COLORS = {
+    "healthy": "green",
+    "warning": "yellow",
+    "critical": "red",
+}
+"""REANA mapping between resource health statuses and click-compatible colors."""
+
+KUBERNETES_MEMORY_UNITS = ["E", "P", "T", "G", "M", "K"]
+"""Kubernetes valid memory units"""
+
+KUBERNETES_MEMORY_FORMAT = r"(?:(?P<value_bytes>\d+)|(?P<value_unit>(\d+[.])?\d+)(?P<unit>[{}])(?P<binary>i?))$".format(
+    "".join(KUBERNETES_MEMORY_UNITS)
+)
+"""Kubernetes valid memory format regular expression e.g. Ki, M, Gi, G, etc."""
+
+statuses = os.getenv("REANA_RUNTIME_KUBERNETES_KEEP_ALIVE_JOBS_WITH_STATUSES", [])
+REANA_RUNTIME_KUBERNETES_KEEP_ALIVE_JOBS_WITH_STATUSES = (
+    statuses.split(",") if statuses else statuses
+)
 """Keep alive Kubernetes user runtime jobs depending on status.
 
 Keep alive both batch workflow jobs and invididual step jobs after termination
@@ -369,3 +433,21 @@ cleaned up.
 Example: ``REANA_RUNTIME_KUBERNETES_KEEP_ALIVE_JOBS_WITH_STATUSES="finished,failed"``
 would keep jobs that terminated successfully and jobs that failed.
 """
+
+REANA_COMPUTE_BACKENDS = {
+    "kubernetes": "Kubernetes",
+    "htcondor": "HTCondor",
+    "slurm": "Slurm",
+}
+"""REANA supported compute backends."""
+
+REANA_WORKFLOW_ENGINES = ["yadage", "cwl", "serial", "snakemake"]
+"""Available workflow engines."""
+
+REANA_DEFAULT_SNAKEMAKE_ENV_IMAGE = "snakemake/snakemake:v6.8.0"
+"""Snakemake default job environment image."""
+
+REANA_JOB_CONTROLLER_CONNECTION_CHECK_SLEEP = float(
+    os.getenv("REANA_JOB_CONTROLLER_CONNECTION_CHECK_SLEEP", "10")
+)
+"""How many seconds to wait between job controller connection checks."""
